==> ParaView-v5.1.2.tar.gz: ParaView-v5.1.2/Qt/Widgets/pqColorButtonEventPlayer.cxx <==
/*=========================================================================

   Program: ParaView
   Module:    pqColorButtonEventPlayer.cxx

   Copyright (c) 2005-2008 Sandia Corporation, Kitware Inc.
   All rights reserved.

   ParaView is a free software; you can redistribute it and/or modify it
   under the terms of the ParaView license version 1.2.

   See License_v1.2.txt for the full ParaView license.
   A copy of this license can be obtained by contacting
   Kitware Inc.
   28 Corporate Drive
   Clifton Park, NY 12065
   USA

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR
CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=========================================================================*/
#include "pqColorButtonEventPlayer.h"

#include "pqTestUtility.h"
#include "pqColorChooserButton.h"

#include <QColor>
#include <QRegExp>

//----------------------------------------------------------------------------
pqColorButtonEventPlayer::pqColorButtonEventPlayer(QObject* parentObject)
  : Superclass(parentObject)
{
}

//----------------------------------------------------------------------------
pqColorButtonEventPlayer::~pqColorButtonEventPlayer()
{
}

//-----------------------------------------------------------------------------
bool pqColorButtonEventPlayer::playEvent(
  QObject* object, const QString& command,
  const QString& arguments, bool& /*error*/)
{
  pqColorChooserButton* button = qobject_cast<pqColorChooserButton*>(object);
  if (!button)
    {
    return false;
    }

  QRegExp regExp("^(\\d+),(\\d+),(\\d+)$");
  if (   (command == pqColorButtonEventPlayer::EVENT_NAME())
      && (regExp.indexIn(arguments) != -1) )
    {
    QColor rgb(regExp.cap(1).toInt(), regExp.cap(2).toInt(),
      regExp.cap(3).toInt());
    button->setChosenColor(rgb);
    return true;
    }
  return false;
}

//-----------------------------------------------------------------------------
const QString &pqColorButtonEventPlayer::EVENT_NAME()
{
  static const QString eventName("setChosenColor");
  return eventName;
}

==> ParaView-v5.2.0.tar.gz: ParaView-v5.2.0/Qt/Widgets/pqColorButtonEventPlayer.cxx <==
/*=========================================================================

   Program: ParaView
   Module:    pqColorButtonEventPlayer.cxx

   Copyright (c) 2005-2008 Sandia Corporation, Kitware Inc.
   All rights reserved.

   ParaView is a free software; you can redistribute it and/or modify it
   under the terms of the ParaView license version 1.2.

   See License_v1.2.txt for the full ParaView license.
   A copy of this license can be obtained by contacting
   Kitware Inc.
   28 Corporate Drive
   Clifton Park, NY 12065
   USA

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR
CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=========================================================================*/
#include "pqColorButtonEventPlayer.h"

#include "pqColorChooserButton.h"
#include "pqTestUtility.h"

#include <QColor>
#include <QRegExp>

//----------------------------------------------------------------------------
pqColorButtonEventPlayer::pqColorButtonEventPlayer(QObject* parentObject)
  : Superclass(parentObject)
{
}

//----------------------------------------------------------------------------
pqColorButtonEventPlayer::~pqColorButtonEventPlayer()
{
}

//-----------------------------------------------------------------------------
bool pqColorButtonEventPlayer::playEvent(
  QObject* object, const QString& command, const QString& arguments, bool& /*error*/)
{
  pqColorChooserButton* button = qobject_cast<pqColorChooserButton*>(object);
  if (!button)
  {
    return false;
  }

  QRegExp regExp("^(\\d+),(\\d+),(\\d+)$");
  if ((command == pqColorButtonEventPlayer::EVENT_NAME()) && (regExp.indexIn(arguments) != -1))
  {
    QColor rgb(regExp.cap(1).toInt(), regExp.cap(2).toInt(), regExp.cap(3).toInt());
    button->setChosenColor(rgb);
    return true;
  }
  return false;
}

//-----------------------------------------------------------------------------
const QString& pqColorButtonEventPlayer::EVENT_NAME()
{
  static const QString eventName("setChosenColor");
  return eventName;
}
